@@ -24,7 +24,7 @@ class Message:
 
     def encode_bstring(self):
         return bytes(
-            self.sid+","+self.dlc+","+self.data[0]+","+self.data[1]+","+self.data[2]+","+self.data[3]+","+self.timestamp+"\n",
+            str(self.sid)+","+str(self.dlc)+","+str(self.data[0])+","+str(self.data[1])+","+str(self.data[2])+","+str(self.data[3])+","+str(self.timestamp)+"\n",
             "utf-8",
         )
     
@@ -75,13 +75,7 @@ class Message:
     def decode_struct(s):
         sid, dlc, *data, timestamp = struct.unpack("HH4HI", s)
 
-        #print(sid, dlc, data, timestamp)
-
-        msg = Message()
-        msg.sid = sid
-        msg.dlc = dlc
-        msg.data = data
-        msg.timestamp = timestamp
+        msg = Message(sid, dlc, data, timestamp)
 
         return msg
 
@@ -92,3 +86,37 @@ class Message:
             data.append(self.data[i] >> 8)
 
         return data
+
+    def __repr__(self):
+        return str(self.encode_json())[1:]
+
+
+def test_encode_json():
+    msg = Message(100, 8, [1,2,3,4], 100)
+    j = json.loads(msg.encode_json())
+    assert j["sid"] == 100
+    assert j["dlc"] == 8
+    assert j["data"] == [1,2,3,4]
+    assert j["timestamp"] == 100
+
+def test_encode_bstring():
+    msg = Message(100, 8, [1,2,3,4], 100)
+    js = msg.encode_bstring().split(b",")
+    js = [int(j) for j in js]
+
+    assert js[0] == 100
+    assert js[1] == 8
+    assert js[2] == 1
+    assert js[3] == 2 
+    assert js[4] == 3 
+    assert js[5] == 4 
+    assert js[6] == 100
+
+def test_encode_struct():
+    msg = Message(100, 8, [1,2,3,4], 100)
+    msg = Message.decode_struct(msg.encode_struct())
+
+    assert msg.sid == 100
+    assert msg.dlc == 8
+    assert msg.data == [1,2,3,4]
+    assert msg.timestamp == 100
